==> Clustering_1.5.tar.gz: Clustering/R/constants.R <==

  CONST_ALGORITHM <- "Algorithm"

  CONST_DISTANCE <- "Distance"

  CONST_CLUSTERS <- "Clusters"

  CONST_DATASET <- "Dataset"

  CONST_TIME <- "Time"

  CONST_RANKING <- "Ranking"

  CONST_FUZZY_CM <- "fuzzy_cm"

  CONST_FUZZY_GG <- "fuzzy_gg"

  CONST_FUZZY_GK <- "fuzzy_gk"

  CONST_HCLUST <- "hclust"

  CONST_APCLUSTERK <- "apclusterK"

  CONST_AGNES <-"agnes"

  CONST_CLARA <- "clara"

  CONST_DAISY <- "daisy"

  CONST_DIANA <- "diana"

  CONST_FANNY <- "fanny"

  CONST_MONA <- "mona"

  CONST_PAM <- "pam"

  CONST_GMM <- "gmm"

  CONST_KMEANS_ARMA <- "kmeans_arma"

  CONST_KMEANS_RCPP <- "kmeans_rcpp"

  CONST_MINI_KMEANS <- "mini_kmeans"

  CONST_GAMA <- "gama"

  CONST_PVCLUST <- "pvclust"

  CONST_ALGORITHM_ADVCLUST <- 'advclust'

  CONST_ALGORITHM_AMAP <- "amap"

  CONST_ALGORITHM_APCLUSTER <- "apcluster"

  CONST_ALGORITHM_CLUSTER <- "cluster"

  CONST_ALGORITHM_CLUSTERR <- "clusterr"

  CONST_ALGORITHM_GAMA <- "gama"

  CONST_ALGORITHM_PVCLUST <- "pvclust"

  CONST_PRECISION_METRIC <- "precision"

  CONST_RECALL_METRIC <- "recall"

  CONST_ENTROPY_METRIC <- "entropy"

  CONST_VARIATION_INFORMATION_METRIC <- "variation_information"

  CONST_F_MEASURE_METRIC <- "f_measure"

  CONST_FOWLKES_MALLOWS_INDEX_METRIC <- "fowlkes_mallows_index"

  CONST_DUNN_METRIC <- "dunn"

  CONST_SILHOUETTE_METRIC <- "silhouette"

  CONST_CONNECTIVITY_METRIC <- "connectivity"

  CONST_TIME_EXTERNAL <- "timeExternal"

  CONST_TIME_INTERNAL <- "timeInternal"

  CONST_EUCLIDEAN <- "euclidean"

  CONST_EUCLIDEAN_DIST <- "eucl_dist"

  CONST_RANDOM_SUBSET <- "random_subset"

  CONST_MANHATTAN <- "manhattan"

  CONST_CORRELATION <- "correlation"

  CONST_MANHATTAN_DIST <- "maha_dist"

  CONST_MINKOWSKI <- "minkowski"

  CONST_GOWER <- "gower"

  CONST_MAHALANOBIS <- "mahalanobis"

  CONST_TIME_DF <- "dataframe"

  CONST_PEARSON_CORRELATION <- "pearson_correlation"

  CONST_HCLUST_EUCLIDEAN <- "hclust_euclidean"

  CONST_APCLUSTERK_EUCLIDEAN <- "apclusterK_euclidean"

  CONST_APCLUSTERK_MANHATTAN <- "apclusterK_manhattan"

  CONST_APCLUSTERK_MINKOWSKI <- "apclusterK_minkowski"

  CONST_AGNES_EUCLIDEAN <- "agnes_euclidean"

  CONST_AGNES_MANHATTAN <- "agnes_manhattan"

  CONST_CLARA_EUCLIDEAN <- "clara_euclidean"

  CONST_CLARA_MANHATTAN <- "clara_manhattan"

  CONST_DAISY_MANHATTAN <- "daisy_manhattan"

  CONST_DAISY_GOWER <- "daisy_gower"

  CONST_DAISY_EUCLIDEAN <- "daisy_euclidean"

  CONST_DIANA_EUCLIDEAN <- "diana_euclidean"

  CONST_FANNY_EUCLIDEAN <- "fanny_euclidean"

  CONST_FANNY_MANHATTAN <- "fanny_manhattan"

  CONST_MONA <- "mona"

  CONST_PAM_EUCLIDEAN <- "pam_euclidean"

  CONST_PAM_MANHATTAN <- "pam_manhattan"

  CONST_GMM_EUCLIDEAN <- "gmm_euclidean"

  CONST_GMM_MANHATTAN <- "gmm_manhattan"

  CONST_GAMA_EUCLIDEAN <- "gama_euclidean"

  CONST_PVCLUST_EUCLIDEAN <-"pvclust_euclidean"

  CONST_PVLCUST_CORRELATION <- "pvclust_correlation"

  CONST_COLUMN_DEFAULT_TABLE <- 5

  CONST_EXTERNAL_METRICS_DEFAULT <- 6

  CONST_INTERNAL_METRICS_DEFAULT <- 6

  CONST_INITIALIZER_STRING <- ""

  CONST_ZERO <- 0

  CONST_ONE <- 1

  CONST_TWO <- 2

  CONST_THREE <- 3

  CONST_NULL <- NULL

  CONST_FALSE <- FALSE

  CONST_TRUE <- TRUE

  CONST_ZERO_DOUBLE <- 0.0

  CONST_NAME_EXTERNAL_REPORT_FILE <- "ExternalReport.txt"

  CONST_NAME_INTERNAL_REPORT_FILE <- "InternalReport.txt"

  CONST_EXTERNAL <- "external"

  CONST_INTERNAL <- "internal"

  CONST_MATRIX <- "matrix"

  CONST_CENTROID <- "centroid"

  CONST_SINGLE <- "single"

==> Clustering_1.7.tar.gz: Clustering/R/constants.R <==

  CONST_ALGORITHM <- "Algorithm"

  CONST_DISTANCE <- "Distance"

  CONST_CLUSTERS <- "Clusters"

  CONST_DATASET <- "Dataset"

  CONST_TIME <- "Time"

  CONST_RANKING <- "Ranking"

  CONST_FUZZY_CM <- "fuzzy_cm"

  CONST_FUZZY_GG <- "fuzzy_gg"

  CONST_FUZZY_GK <- "fuzzy_gk"

  CONST_HCLUST <- "hclust"

  CONST_APCLUSTERK <- "apclusterK"

  CONST_AGNES <-"agnes"

  CONST_CLARA <- "clara"

  CONST_DAISY <- "daisy"

  CONST_DIANA <- "diana"

  CONST_FANNY <- "fanny"

  CONST_MONA <- "mona"

  CONST_PAM <- "pam"

  CONST_GMM <- "gmm"

  CONST_KMEANS_ARMA <- "kmeans_arma"

  CONST_KMEANS_RCPP <- "kmeans_rcpp"

  CONST_MINI_KMEANS <- "mini_kmeans"

  CONST_GAMA <- "gama"

  CONST_PVCLUST <- "pvclust"

  CONST_ALGORITHM_ADVCLUST <- 'advclust'

  CONST_ALGORITHM_AMAP <- "amap"

  CONST_ALGORITHM_APCLUSTER <- "apcluster"

  CONST_ALGORITHM_CLUSTER <- "cluster"

  CONST_ALGORITHM_CLUSTERR <- "clusterr"

  CONST_ALGORITHM_GAMA <- "gama"

  CONST_ALGORITHM_PVCLUST <- "pvclust"

  CONST_PRECISION_METRIC <- "precision"

  CONST_PRECISION_METRIC_VAR <- "precisionVar"

  CONST_RECALL_METRIC <- "recall"

  CONST_RECALL_METRIC_VAR <- "recallVar"

  CONST_ENTROPY_METRIC <- "entropy"

  CONST_ENTROPY_METRIC_VAR <- "entropyVar"

  CONST_VARIATION_INFORMATION_METRIC <- "variation_information"

  CONST_VARIATION_INFORMATION_METRIC_VAR <- "variation_informationVar"

  CONST_F_MEASURE_METRIC <- "f_measure"

  CONST_F_MEASURE_METRIC_VAR <- "f_measureVar"

  CONST_FOWLKES_MALLOWS_INDEX_METRIC <- "fowlkes_mallows_index"

  CONST_FOWLKES_MALLOWS_INDEX_METRIC_VAR <- "fowlkes_mallows_indexVar"

  CONST_DUNN_METRIC <- "dunn"

  CONST_DUNN_METRIC_VAR <- "dunnVar"

  CONST_SILHOUETTE_METRIC <- "silhouette"

  CONST_SILHOUETTE_METRIC_VAR <- "silhouetteVar"

  CONST_CONNECTIVITY_METRIC <- "connectivity"

  CONST_CONNECTIVITY_METRIC_VAR <- "connectivityVar"

  CONST_TIME_EXTERNAL <- "timeExternal"

  CONST_TIME_EXTERNAL_VAR <- "timeExternalVar"

  CONST_TIME_INTERNAL <- "timeInternal"

  CONST_TIME_INTERNAL_VAR <- "timeInternalVar"

  CONST_EUCLIDEAN <- "euclidean"

  CONST_EUCLIDEAN_DIST <- "eucl_dist"

  CONST_RANDOM_SUBSET <- "random_subset"

  CONST_MANHATTAN <- "manhattan"

  CONST_CORRELATION <- "correlation"

  CONST_MANHATTAN_DIST <- "maha_dist"

  CONST_MINKOWSKI <- "minkowski"

  CONST_GOWER <- "gower"

  CONST_MAHALANOBIS <- "mahalanobis"

  CONST_TIME_DF <- "dataframe"

  CONST_PEARSON_CORRELATION <- "pearson_correlation"

  CONST_HCLUST_EUCLIDEAN <- "hclust_euclidean"

  CONST_APCLUSTERK_EUCLIDEAN <- "apclusterK_euclidean"

  CONST_APCLUSTERK_MANHATTAN <- "apclusterK_manhattan"

  CONST_APCLUSTERK_MINKOWSKI <- "apclusterK_minkowski"

  CONST_AGNES_EUCLIDEAN <- "agnes_euclidean"

  CONST_AGNES_MANHATTAN <- "agnes_manhattan"

  CONST_CLARA_EUCLIDEAN <- "clara_euclidean"

  CONST_CLARA_MANHATTAN <- "clara_manhattan"

  CONST_DAISY_MANHATTAN <- "daisy_manhattan"

  CONST_DAISY_GOWER <- "daisy_gower"

  CONST_DAISY_EUCLIDEAN <- "daisy_euclidean"

  CONST_DIANA_EUCLIDEAN <- "diana_euclidean"

  CONST_FANNY_EUCLIDEAN <- "fanny_euclidean"

  CONST_FANNY_MANHATTAN <- "fanny_manhattan"

  CONST_MONA <- "mona"

  CONST_PAM_EUCLIDEAN <- "pam_euclidean"

  CONST_PAM_MANHATTAN <- "pam_manhattan"

  CONST_GMM_EUCLIDEAN <- "gmm_euclidean"

  CONST_GMM_MANHATTAN <- "gmm_manhattan"

  CONST_GAMA_EUCLIDEAN <- "gama_euclidean"

  CONST_PVCLUST_EUCLIDEAN <-"pvclust_euclidean"

  CONST_PVLCUST_CORRELATION <- "pvclust_correlation"

  CONST_COLUMN_DEFAULT_TABLE <- 5

  CONST_EXTERNAL_METRICS_DEFAULT <- 6

  CONST_INTERNAL_METRICS_DEFAULT <- 6

  CONST_INITIALIZER_STRING <- ""

  CONST_ZERO <- 0

  CONST_ONE <- 1

  CONST_TWO <- 2

  CONST_THREE <- 3

  CONST_NULL <- NULL

  CONST_FALSE <- F

  CONST_TRUE <- T

  CONST_ZERO_DOUBLE <- 0.0

  CONST_NAME_EXTERNAL_REPORT_FILE <- "ExternalReport.txt"

  CONST_NAME_INTERNAL_REPORT_FILE <- "InternalReport.txt"

  CONST_EXTERNAL <- "external"

  CONST_INTERNAL <- "internal"

  CONST_MATRIX <- "matrix"

  CONST_CENTROID <- "centroid"

  CONST_SINGLE <- "single"

  CONST_FORMAT_ARFF_FILE <- "arff"

  CONST_NAME_EXTERNAL_FILA_LATEX = "external_data.tex"

  CONST_NAME_INTERNAL_FILA_LATEX = "internal_data.tex"
